summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/bus/isa/cga.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/bus/isa/cga.h')
-rw-r--r--src/devices/bus/isa/cga.h76
1 files changed, 38 insertions, 38 deletions
diff --git a/src/devices/bus/isa/cga.h b/src/devices/bus/isa/cga.h
index 8fdabd41ebb..54db66e4e10 100644
--- a/src/devices/bus/isa/cga.h
+++ b/src/devices/bus/isa/cga.h
@@ -26,8 +26,8 @@ class isa8_cga_device :
public:
// construction/destruction
- isa8_cga_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
- isa8_cga_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, UINT32 clock, const char *shortname, const char *source);
+ isa8_cga_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
+ isa8_cga_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, uint32_t clock, const char *shortname, const char *source);
virtual MC6845_UPDATE_ROW( crtc_update_row );
MC6845_UPDATE_ROW( cga_text_inten_update_row );
@@ -53,34 +53,34 @@ protected:
virtual void device_start() override;
virtual void device_reset() override;
public:
- void mode_control_w(UINT8 data);
+ void mode_control_w(uint8_t data);
void set_palette_luts();
- void plantronics_w(UINT8 data);
+ void plantronics_w(uint8_t data);
virtual DECLARE_READ8_MEMBER( io_read );
virtual DECLARE_WRITE8_MEMBER( io_write );
DECLARE_WRITE_LINE_MEMBER( hsync_changed );
DECLARE_WRITE_LINE_MEMBER( vsync_changed );
- virtual UINT32 screen_update(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect);
+ virtual uint32_t screen_update(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect);
MC6845_RECONFIGURE(reconfigure);
public:
int m_framecnt;
- UINT8 m_mode_control; /* wo 0x3d8 */
- UINT8 m_color_select; /* wo 0x3d9 */
- //UINT8 m_status; //unused? /* ro 0x3da */
+ uint8_t m_mode_control; /* wo 0x3d8 */
+ uint8_t m_color_select; /* wo 0x3d9 */
+ //uint8_t m_status; //unused? /* ro 0x3da */
int m_update_row_type, m_y;
- UINT8 m_palette_lut_2bpp[4];
+ uint8_t m_palette_lut_2bpp[4];
offs_t m_chr_gen_offset[4];
- UINT8 m_font_selection_mask;
- UINT8 *m_chr_gen_base;
- UINT8 *m_chr_gen;
- UINT8 m_vsync;
- UINT8 m_hsync;
+ uint8_t m_font_selection_mask;
+ uint8_t *m_chr_gen_base;
+ uint8_t *m_chr_gen;
+ uint8_t m_vsync;
+ uint8_t m_hsync;
size_t m_vram_size;
- std::vector<UINT8> m_vram;
+ std::vector<uint8_t> m_vram;
bool m_superimpose;
- UINT8 m_plantronics; /* This should be moved into the appropriate subclass */
+ uint8_t m_plantronics; /* This should be moved into the appropriate subclass */
offs_t m_start_offset;
required_device<palette_device> m_palette;
required_device<screen_device> m_screen;
@@ -97,8 +97,8 @@ class isa8_cga_superimpose_device :
{
public:
// construction/destruction
- isa8_cga_superimpose_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
- isa8_cga_superimpose_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, UINT32 clock, const char *shortname, const char *source);
+ isa8_cga_superimpose_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
+ isa8_cga_superimpose_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, uint32_t clock, const char *shortname, const char *source);
};
// device type definition
@@ -112,7 +112,7 @@ class isa8_cga_poisk2_device :
{
public:
// construction/destruction
- isa8_cga_poisk2_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
+ isa8_cga_poisk2_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
// optional information overrides
virtual const tiny_rom_entry *device_rom_region() const override;
};
@@ -128,7 +128,7 @@ class isa8_cga_pc1512_device :
{
public:
// construction/destruction
- isa8_cga_pc1512_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
+ isa8_cga_pc1512_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
// optional information overrides
virtual ioport_constructor device_input_ports() const override;
virtual const tiny_rom_entry *device_rom_region() const override;
@@ -142,17 +142,17 @@ protected:
virtual void device_reset() override;
public:
- UINT8 m_write;
- UINT8 m_read;
- UINT8 m_mc6845_address;
- UINT8 m_mc6845_locked_register[31];
+ uint8_t m_write;
+ uint8_t m_read;
+ uint8_t m_mc6845_address;
+ uint8_t m_mc6845_locked_register[31];
public:
// Static information
// mapping of the 4 planes into videoram
// (text data should be readable at videoram+0)
static const offs_t vram_offset[4];
- static const UINT8 mc6845_writeonce_register[31];
+ static const uint8_t mc6845_writeonce_register[31];
virtual DECLARE_READ8_MEMBER( io_read ) override;
virtual DECLARE_WRITE8_MEMBER( io_write ) override;
@@ -170,7 +170,7 @@ class isa8_wyse700_device :
{
public:
// construction/destruction
- isa8_wyse700_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
+ isa8_wyse700_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
// optional information overrides
virtual const tiny_rom_entry *device_rom_region() const override;
@@ -182,12 +182,12 @@ protected:
public:
virtual DECLARE_READ8_MEMBER( io_read ) override;
virtual DECLARE_WRITE8_MEMBER( io_write ) override;
- virtual UINT32 screen_update(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect) override;
- void change_resolution(UINT8 mode);
+ virtual uint32_t screen_update(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect) override;
+ void change_resolution(uint8_t mode);
- UINT8 m_bank_offset;
- UINT8 m_bank_base;
- UINT8 m_control;
+ uint8_t m_bank_offset;
+ uint8_t m_bank_base;
+ uint8_t m_control;
};
// device type definition
@@ -200,7 +200,7 @@ class isa8_ec1841_0002_device :
{
public:
// construction/destruction
- isa8_ec1841_0002_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
+ isa8_ec1841_0002_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
protected:
// device-level overrides
@@ -211,7 +211,7 @@ public:
virtual DECLARE_READ8_MEMBER( io_read ) override;
virtual DECLARE_WRITE8_MEMBER( io_write ) override;
- UINT8 m_p3df;
+ uint8_t m_p3df;
DECLARE_READ8_MEMBER( char_ram_read );
DECLARE_WRITE8_MEMBER( char_ram_write );
};
@@ -226,7 +226,7 @@ class isa8_cga_iskr1030m_device :
{
public:
// construction/destruction
- isa8_cga_iskr1030m_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
+ isa8_cga_iskr1030m_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
virtual const tiny_rom_entry *device_rom_region() const override;
};
@@ -240,7 +240,7 @@ class isa8_cga_iskr1031_device :
{
public:
// construction/destruction
- isa8_cga_iskr1031_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
+ isa8_cga_iskr1031_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
virtual const tiny_rom_entry *device_rom_region() const override;
};
@@ -254,7 +254,7 @@ class isa8_cga_mc1502_device :
{
public:
// construction/destruction
- isa8_cga_mc1502_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
+ isa8_cga_mc1502_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
// optional information overrides
virtual const tiny_rom_entry *device_rom_region() const override;
};
@@ -268,7 +268,7 @@ class isa8_cga_m24_device :
{
public:
// construction/destruction
- isa8_cga_m24_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
+ isa8_cga_m24_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
virtual machine_config_constructor device_mconfig_additions() const override;
// optional information overrides
//virtual const rom_entry *device_rom_region() const;
@@ -280,7 +280,7 @@ public:
protected:
virtual void device_reset() override;
private:
- UINT8 m_mode2, m_index;
+ uint8_t m_mode2, m_index;
};
// device type definition